BitcoinNetwork enum

Bitcoin network types

Inheritance
Available extensions

Values

mainnet → const BitcoinNetwork
const BitcoinNetwork(0xe8f3e1e3)
testnet → const BitcoinNetwork
const BitcoinNetwork(0xf4f3e5f4)
regtest → const BitcoinNetwork
const BitcoinNetwork(0xfabfb5da)
simnet → const BitcoinNetwork
const BitcoinNetwork(0x12141c16)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
magic → int
Network magic number for message headers
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMagic(int magic) → BitcoinNetwork?
Get network from magic number

Constants

values → const List<BitcoinNetwork>
A constant List of the values in this enum, in order of their declaration.