blockHash method
Computes the block identifier hash for this block header.
Implementation
Hash blockHash() {
final data = serialize();
return HashUtils.doubleSha256(data);
}
Computes the block identifier hash for this block header.
Hash blockHash() {
final data = serialize();
return HashUtils.doubleSha256(data);
}