timestamp property
Time the block was created. This is encoded as a uint32 on the wire and therefore is limited to 2106.
Implementation
final DateTime timestamp;
Time the block was created. This is encoded as a uint32 on the wire and therefore is limited to 2106.
final DateTime timestamp;