ChainTip class

Represents the consensus chain tip

Constructors

ChainTip({required Hash blockHash, required int height, required DateTime lastUpdated, required int peerCount, required double confidence, required List<String> reportingPeers})

Properties

age → Duration
Age of this tip
no setter
blockHash → Hash
final
confidence → double
final
hashCode → int
The hash code for this object.
no setteroverride
height → int
final
isCurrent → bool
Whether this tip is considered current
no setter
lastUpdated → DateTime
final
peerCount → int
final
reportingPeers → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override