ChainTipEvent class

Event fired when chain tip changes

Constructors

ChainTipEvent({ChainTip? oldTip, required ChainTip newTip, required ChainTipEventType type, String? triggeringPeer, required String description})

Properties

description → String
final
hashCode → int
The hash code for this object.
no setterinherited
heightChange → int
Height change (positive for increase, negative for decrease)
no setter
isReorganization → bool
Whether this represents a blockchain reorganization
no setter
newTip → ChainTip
final
oldTip → ChainTip?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggeringPeer → String?
final
type → ChainTipEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited