HashUtils class

Utility functions for hash creation

Constructors

HashUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

doubleSha256(Uint8List data) → Hash
Calculate double SHA256 hash
hashFromString(String data) → Hash
Create hash from string data
sha256Hash(Uint8List data) → Hash
Calculate single SHA256 hash