MessagePriority enum

Priority levels for messages

Inheritance
Available extensions

Values

critical → const MessagePriority
const MessagePriority(0)
high → const MessagePriority
const MessagePriority(1)
normal → const MessagePriority
const MessagePriority(2)
low → const MessagePriority
const MessagePriority(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
level → int
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MessagePriority>
A constant List of the values in this enum, in order of their declaration.