MessageQueueConfig class

Configuration for message queue behavior

Constructors

MessageQueueConfig({int maxSize = 1000, Duration maxAge = const Duration(minutes: 5), bool dropOldestOnOverflow = true, bool priorityEnabled = true})
const

Properties

dropOldestOnOverflow → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maxAge → Duration
final
maxSize → int
final
priorityEnabled → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited