MessageQueueOverflowException class

Exception thrown when message queue overflows

Inheritance

Constructors

MessageQueueOverflowException(int queueSize, int maxSize)
const

Properties

cause Object?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxSize int
final
message String
finalinherited
queueSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited