isEmpty property
bool
get
isEmpty
Checks if this message has no block locator hashes.
Implementation
bool get isEmpty => blockLocatorHashes.isEmpty;
Checks if this message has no block locator hashes.
bool get isEmpty => blockLocatorHashes.isEmpty;