decode method
Decode message from bytes
Implementation
@override
void decode(Uint8List data, int protocolVersion, MessageEncoding encoding) {
// Since headers list is final, decoding logic is handled in factory constructor
// This method is required by the interface but not used for immutable classes
}