MsgMemPool class

MsgMemPool implements the Message interface and represents a bitcoin mempool message. It is used to request a list of transactions still in the active memory pool of a relay.

This message has no payload and was not added until protocol version 60002.

Inheritance

Constructors

MsgMemPool()
Creates a new MsgMemPool message.
MsgMemPool.deserialize(Uint8List data)
Deserializes a MsgMemPool from byte data.
factory

Properties

command → String
Get the command string for this message type
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
maxPayloadLength → int
Get maximum payload length for this message type
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, int protocolVersion, MessageEncoding encoding) → void
Decode message from bytes
override
encode(int protocolVersion, MessageEncoding encoding) → Uint8List
Encode message to bytes
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(int protocolVersion, BitcoinNetwork network) → Uint8List
Serialize complete message with header
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

registerWithFactory() → void
Register this message type with the factory.