code property
RejectCode is a code indicating why the command was rejected. It is encoded as a uint8 on the wire.
Implementation
final RejectCode code;
RejectCode is a code indicating why the command was rejected. It is encoded as a uint8 on the wire.
final RejectCode code;