hash property
Hash identifies a specific block or transaction that was rejected and therefore only applies to MsgBlock and MsgTx messages.
Implementation
final Hash? hash;
Hash identifies a specific block or transaction that was rejected and therefore only applies to MsgBlock and MsgTx messages.
final Hash? hash;