PeerConfig class

Configuration for peer behavior

Constructors

PeerConfig({Duration handshakeTimeout = const Duration(seconds: 10), Duration pingInterval = const Duration(minutes: 2), Duration pongTimeout = const Duration(seconds: 30), int maxUnhealthyScore = 10, int protocolVersion = 70016, String userAgent = '/spiffynode:0.1.0/', bool enablePingPong = true, int startHeight = 0})
const

Properties

enablePingPong → bool
final
handshakeTimeout → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
maxUnhealthyScore → int
final
pingInterval → Duration
final
pongTimeout → Duration
final
protocolVersion → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startHeight → int
final
userAgent → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited