PeerConnectionConfig class

Configuration for peer connection

Constructors

PeerConnectionConfig({Duration connectTimeout = const Duration(seconds: 10), Duration readTimeout = const Duration(minutes: 5), Duration writeTimeout = const Duration(seconds: 30), int maxRetries = 3, Duration retryDelay = const Duration(seconds: 5), MessageQueueConfig queueConfig = const MessageQueueConfig()})
const

Properties

connectTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
queueConfig MessageQueueConfig
final
readTimeout Duration
final
retryDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeTimeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited