PeerHandlerI class abstract

Interface for handling incoming messages from peers

Constructors

PeerHandlerI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleAddresses(WireMessage msg, PeerI peer) Future<void>
Handle peer address announcements
handleBlock(WireMessage msg, PeerI peer) Future<void>
Handle incoming block data
handleBlockAnnouncement(InvVect msg, PeerI peer) Future<void>
Handle announcement of new block availability (INV message)
handleHeaders(WireMessage msg, PeerI peer) Future<void>
Handle incoming block headers
handleTransaction(WireMessage msg, PeerI peer) Future<void>
Handle incoming transaction data
handleTransactionAnnouncement(InvVect msg, PeerI peer) Future<void>
Handle announcement of new transaction availability (INV message)
handleTransactionRejection(WireMessage rejMsg, PeerI peer) Future<void>
Handle transaction rejection from peer
handleTransactionSent(WireMessage msg, PeerI peer) Future<void>
Handle notification that a transaction was successfully sent to peer
handleTransactionsGet(List<InvVect> msgs, PeerI peer) Future<List<Uint8List>>
Handle requests for transactions (INV messages requesting TX data) Returns list of raw transaction bytes, or empty list if not found
handleVersion(WireMessage msg, PeerI peer) Future<void>
Handle peer version message during handshake
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited