handleTransactionSent abstract method
Handle notification that a transaction was successfully sent to peer
Implementation
Future<void> handleTransactionSent(WireMessage msg, PeerI peer);
Handle notification that a transaction was successfully sent to peer
Future<void> handleTransactionSent(WireMessage msg, PeerI peer);