announceTransaction abstract method
Announce a transaction hash to specified peers Returns list of peers that successfully received the announcement
Implementation
Future<List<PeerI>> announceTransaction(Hash txHash, List<PeerI> peers);
Announce a transaction hash to specified peers Returns list of peers that successfully received the announcement
Future<List<PeerI>> announceTransaction(Hash txHash, List<PeerI> peers);