requestBlock abstract method

Future<PeerI?> requestBlock(
  1. Hash blockHash
)

Request a block from the best available peer Returns the peer handling the request, or null if no peers available

Implementation

Future<PeerI?> requestBlock(Hash blockHash);