requestTransaction abstract method

Future<PeerI?> requestTransaction(
  1. Hash txHash
)

Request a transaction from the best available peer Returns the peer handling the request, or null if no peers available

Implementation

Future<PeerI?> requestTransaction(Hash txHash);