ProcessingResult class

Result of message processing attempt

Constructors

ProcessingResult({WireMessage? message, required int bytesConsumed, String? error})
const

Properties

bytesConsumed → int
final
error → String?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMessage → bool
no setter
message → WireMessage?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited