RejectCode enum

RejectCode represents a numeric value by which a remote peer indicates why a message was rejected.

Inheritance
Available extensions

Values

malformed → const RejectCode
const RejectCode(0x01)
invalid → const RejectCode
const RejectCode(0x10)
obsolete → const RejectCode
const RejectCode(0x11)
duplicate → const RejectCode
const RejectCode(0x12)
nonstandard → const RejectCode
const RejectCode(0x40)
dust → const RejectCode
const RejectCode(0x41)
insufficientFee → const RejectCode
const RejectCode(0x42)
checkpoint → const RejectCode
const RejectCode(0x43)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the RejectCode in human-readable form.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RejectCode?
Get RejectCode from numeric value

Constants

values → const List<RejectCode>
A constant List of the values in this enum, in order of their declaration.