TxIn class

Bitcoin transaction input

Constructors

TxIn({required Hash previousOutPointHash, required int previousOutPointIndex, required Uint8List signatureScript, int sequence = 0xffffffff})
TxIn.coinbase(Uint8List coinbaseData)
Create coinbase transaction input (for mining rewards)
factory
TxIn.deserialize(Uint8List data, int offset)
Deserialize transaction input
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCoinbase → bool
Check if this is a coinbase input
no setter
previousOutPointHash ↔ Hash
getter/setter pair
previousOutPointIndex ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ int
getter/setter pair
serializedSize → int
Size in bytes when serialized
no setter
signatureScript ↔ Uint8List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → Uint8List
Serialize transaction input
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited