WireMessage class abstract

Abstract base class for all wire protocol messages

Implementers

Constructors

WireMessage()

Properties

command → String
Get the command string for this message type
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxPayloadLength → int
Get maximum payload length for this message type
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, int protocolVersion, MessageEncoding encoding) → void
Decode message from bytes
encode(int protocolVersion, MessageEncoding encoding) → Uint8List
Encode message to bytes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(int protocolVersion, BitcoinNetwork network) → Uint8List
Serialize complete message with header
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited