ChainTipTrackerConfig class
Configuration for chain tip tracker
Constructors
Properties
- consensusThreshold → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxReorgDepth → int
-
final
- minPeersForConsensus → int
-
final
- reorgConfirmationTime → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleTimeout → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited