Commands class
Bitcoin protocol commands
Constructors
- Commands()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- addr → const String
- authch → const String
- authresp → const String
- block → const String
- cfcheckpt → const String
- cfheaders → const String
- cfilter → const String
- extendedtx → const String
- extmsg → const String
- feefilter → const String
- filteradd → const String
- filterclear → const String
- filterload → const String
- getaddr → const String
- getblocks → const String
- getcfcheckpt → const String
- getcfheaders → const String
- getcfilters → const String
- getdata → const String
- getheaders → const String
- headers → const String
- inv → const String
- mempool → const String
- merkleblock → const String
- notfound → const String
- ping → const String
- pong → const String
- protoconf → const String
- reject → const String
- sendcmpct → const String
- sendheaders → const String
- tx → const String
- verack → const String
- version → const String