ConnectionManagerConfig class

Configuration for connection manager

Constructors

ConnectionManagerConfig({int maxConnections = 8, Duration reconnectDelay = const Duration(seconds: 30), int maxReconnectAttempts = 3, Duration healthCheckInterval = const Duration(minutes: 1), Duration connectionTimeout = const Duration(seconds: 30), PeerConnectionConfig defaultConnectionConfig = const PeerConnectionConfig()})
const

Properties

connectionTimeout Duration
final
defaultConnectionConfig PeerConnectionConfig
final
hashCode int
The hash code for this object.
no setterinherited
healthCheckInterval Duration
final
maxConnections int
final
maxReconnectAttempts int
final
reconnectDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited