InvVect class

Inventory vector represents an item in an inventory message

Constructors

InvVect({required int type, required Hash hash})
InvVect.block(Hash blockHash)
Create block inventory
factory
InvVect.deserialize(Uint8List data, int offset)
Deserialize from bytes
factory
InvVect.transaction(Hash txHash)
Create transaction inventory
factory

Properties

hash Hash
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
final
typeName String
Get type name as string
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize to bytes
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override