MessageHeader class

Bitcoin message header

Constructors

MessageHeader({required BitcoinNetwork network, required String command, required int payloadLength, required Uint8List checksum})
MessageHeader.deserialize(Uint8List data)
Deserialize header from bytes
factory

Properties

checksum Uint8List
final
command String
final
hashCode int
The hash code for this object.
no setterinherited
network BitcoinNetwork
final
payloadLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize header to bytes
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited