MessageProcessor class

Processes raw data streams into Bitcoin protocol messages

Constructors

MessageProcessor({required BitcoinNetwork network, Logger? logger})

Properties

bufferSize int
Get current buffer size (for debugging)
no setter
bytesProcessed int
no setter
errors int
no setter
hasError bool
Check if processor is in error state
no setter
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
messagesProcessed int
Statistics
no setter
network BitcoinNetwork
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ProcessingState
Current processing state
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processData(Uint8List data) List<ProcessingResult>
Process incoming raw data and extract complete messages
reset() → void
Reset processor to initial state
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited