MsgPing class
Bitcoin ping message for keepalive
- Inheritance
-
- Object
- WireMessage
- RegisterableMessage
- MsgPing
Properties
- command → String
-
Get the command string for this message type
no setteroverride
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxPayloadLength → int
-
Get maximum payload length for this message type
no setteroverride
- nonce ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Uint8List data, int protocolVersion, MessageEncoding encoding) → void -
Decode message from bytes
override
-
encode(
int protocolVersion, MessageEncoding encoding) → Uint8List -
Encode message to bytes
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
int protocolVersion, BitcoinNetwork network) → Uint8List -
Serialize complete message with header
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
deserialize(
Uint8List data, int protocolVersion, MessageEncoding encoding) → MsgPing - Factory method for deserialization
-
registerWithFactory(
) → void - Register this message type with the factory