MsgReject class
MsgReject implements the Message interface and represents a bitcoin reject message.
This message was not added until protocol version 70002.
- Inheritance
-
- Object
- WireMessage
- RegisterableMessage
- MsgReject
Constructors
- MsgReject({required String cmd, required RejectCode code, required String reason, Hash? hash})
- Creates a new MsgReject message.
- MsgReject.deserialize(Uint8List data)
-
Deserializes a MsgReject from byte data.
factory
Properties
- cmd → String
-
Cmd is the command for the message which was rejected such as
CmdBlock or CmdTx. This can be obtained from the Command function
of a Message.
final
- code → RejectCode
-
RejectCode is a code indicating why the command was rejected.
It is encoded as a uint8 on the wire.
final
- command → String
-
Get the command string for this message type
no setteroverride
- hash → Hash?
-
Hash identifies a specific block or transaction that was rejected
and therefore only applies to MsgBlock and MsgTx messages.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxPayloadLength → int
-
Get maximum payload length for this message type
no setteroverride
- reason → String
-
Reason is a human-readable string with specific details (over and
above the reject code) about why the command was rejected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Uint8List data, int protocolVersion, MessageEncoding encoding) → void -
Decode message from bytes
override
-
encode(
int protocolVersion, MessageEncoding encoding) → Uint8List -
Encode message to bytes
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
int protocolVersion, BitcoinNetwork network) → Uint8List -
Serialize complete message with header
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
registerWithFactory(
) → void - Register this message type with the factory.