cmd property
Cmd is the command for the message which was rejected such as CmdBlock or CmdTx. This can be obtained from the Command function of a Message.
Implementation
final String cmd;
Cmd is the command for the message which was rejected such as CmdBlock or CmdTx. This can be obtained from the Command function of a Message.
final String cmd;