PeerChainTip class

Represents a blockchain tip from a specific peer

Constructors

PeerChainTip({required String peerId, required Hash blockHash, required int height, required DateTime reportedAt, required ChainTipSource source, int confidence = 1})

Properties

age Duration
Age of this tip report
no setter
blockHash Hash
final
confidence int
final
hashCode int
The hash code for this object.
no setteroverride
height int
final
isStale bool
Whether this tip is considered stale
no setter
peerId String
final
reportedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source ChainTipSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override