PeerI class abstract
Interface for individual peer connections to BitcoinSV network
- Implementers
Constructors
- PeerI()
Properties
- connected → bool
-
Whether the peer is currently connected
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHealthy → bool
-
Whether the peer is considered healthy (responding to pings, etc.)
no setter
-
isUnhealthyStream
→ Stream<
void> -
Stream that emits when peer becomes unhealthy
no setter
- network → BitcoinNetwork
-
The Bitcoin network this peer operates on
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
announceBlock(
Hash blockHash) → Future< void> - Announce a block hash to this peer
-
announceTransaction(
Hash txHash) → Future< void> - Announce a transaction hash to this peer
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestBlock(
Hash blockHash) → Future< void> - Request a block from this peer
-
requestTransaction(
Hash txHash) → Future< void> - Request a transaction from this peer
-
restart(
) → Future< void> - Restart the peer connection
-
shutdown(
) → Future< void> - Shutdown the peer connection
-
toString(
) → String -
String representation of the peer (typically address:port)
override
-
writeMessage(
WireMessage msg) → Future< void> - Send a wire protocol message to the peer
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited