PeerManagerConfig class
Configuration for peer manager behavior
Constructors
- PeerManagerConfig({int minPeers = 3, int maxPeers = 8, Duration peerConnectTimeout = const Duration(seconds: 30), Duration announcementCooldown = const Duration(milliseconds: 100), int maxAnnouncementBatch = 3, bool enableHealthMonitoring = true, Duration healthCheckInterval = const Duration(minutes: 2), PeerConfig defaultPeerConfig = const PeerConfig()})
-
const
Properties
- announcementCooldown → Duration
-
final
- defaultPeerConfig → PeerConfig
-
final
- enableHealthMonitoring → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthCheckInterval → Duration
-
final
- maxAnnouncementBatch → int
-
final
- maxPeers → int
-
final
- minPeers → int
-
final
- peerConnectTimeout → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited