PeerManagerI class abstract

Interface for managing multiple peers in the BitcoinSV network

Implementers

Constructors

PeerManagerI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPeer(PeerI peer) Future<void>
Add a peer to the manager Throws PeerNetworkMismatchException if peer network doesn't match
announceBlock(Hash blockHash, List<PeerI> peers) Future<List<PeerI>>
Announce a block hash to specified peers Returns list of peers that successfully received the announcement
announceTransaction(Hash txHash, List<PeerI> peers) Future<List<PeerI>>
Announce a transaction hash to specified peers Returns list of peers that successfully received the announcement
getPeers() List<PeerI>
Get all currently managed peers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestBlock(Hash blockHash) Future<PeerI?>
Request a block from the best available peer Returns the peer handling the request, or null if no peers available
requestTransaction(Hash txHash) Future<PeerI?>
Request a transaction from the best available peer Returns the peer handling the request, or null if no peers available
shutdown() Future<void>
Shutdown the peer manager and all associated peers
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited