QueuedMessage class

Queued message with metadata

Constructors

QueuedMessage({required WireMessage message, required MessagePriority priority, DateTime? queuedAt, Completer<void>? completer})

Properties

age Duration
Age of this message in the queue
no setter
completer Completer<void>?
final
hashCode int
The hash code for this object.
no setterinherited
message WireMessage
final
priority MessagePriority
final
queuedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited