RegisterableMessage class abstract

Base class for messages that can be registered with the factory

Inheritance
Implementers

Constructors

RegisterableMessage()

Properties

command String
Get the command string for this message type
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxPayloadLength int
Get maximum payload length for this message type
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, int protocolVersion, MessageEncoding encoding) → void
Decode message from bytes
inherited
encode(int protocolVersion, MessageEncoding encoding) Uint8List
Encode message to bytes
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(int protocolVersion, BitcoinNetwork network) Uint8List
Serialize complete message with header
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

register<T extends RegisterableMessage>(String command, T deserializer(Uint8List data, int protocolVersion, MessageEncoding encoding), T constructor()) → void
Register this message type with the factory