TxOut class

Bitcoin transaction output

Constructors

TxOut({required int value, required Uint8List pkScript})
TxOut.deserialize(Uint8List data, int offset)
Deserialize transaction output
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isDust bool
Check if output is dust (too small to be economical)
no setter
pkScript Uint8List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializedSize int
Size in bytes when serialized
no setter
value int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize transaction output
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited