VarInt class

Helper class for reading variable-length integers

Constructors

VarInt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

read(ByteData buffer, int offset) int
Read variable integer from byte data
size(int value) int
Get size of variable integer encoding
write(List<int> bytes, int value) → void
Write variable integer to byte list